#![cfg(test)]

use http::header::{CONTENT_TYPE, LINK};
use url::Url;

use crate::{
    http::CONTENT_TYPE_JSON,
    standards::indieauth::{Scopes, ServerMetadata},
};

use super::{ClientId, CodeChallenge};

#[test]
fn server_metadata_new_authorization_request_url() -> miette::Result<()> {
    let issuer: Url = "https://example.com".parse().unwrap();
    let metadata = ServerMetadata {
        authorization_endpoint: format!("{}/auth", issuer.as_str()).parse().unwrap(),
        token_endpoint: format!("{}/token", issuer.as_str()).parse().unwrap(),
        introspection_endpoint: format!("{}/introspect", issuer.as_str()).parse().ok(),
        code_challenge_methods_supported: vec!["S256".to_string()],
        scopes_supported: Scopes::minimal(),
        issuer,
    };

    let (code_challenge, code_challenge_method) =
        CodeChallenge::generate(super::CodeChallengeMethod::S256);
    let formed_url = metadata.new_authorization_request_url(super::RequestFields {
        client_id: ClientId::new("http://client.example.com")?,
        redirect_uri: "http://client.example.com/redirect".parse::<Url>().unwrap(),
        state: "nu-state".to_string(),
        challenge: code_challenge,
        challenge_method: code_challenge_method,
        scope: Default::default(),
    })?;

    assert!(
        !formed_url.query().unwrap_or_default().contains("scope="),
        "does not includes an empty scope string"
    );

    assert!(
        formed_url
            .query()
            .unwrap_or_default()
            .contains("state=nu-state"),
        "includes the provided state value"
    );

    Ok(())
}
